function D = kotSchafferDifferential_logistic_intval(a, b, c, mu, N)

%--------------------------------------------------------------------------
%
%Note: In this file ``the paper'' refers to 
%
%      Fourier-Taylor Approximation of Unstable Manifolds for Compact Maps: 
%          Numerical Implementation and Computer Assisted Error Bounds
%
%
%
%The program computes the jacobian matrix for the the cosine series 
%discretization of the Kot-Schaffer map.  The map is assumed to have 
%logistic nonlinearity.
%
%More precisely the program returns the matrix associated with the differential
%of the mapping defined by Equation (18) on page 13 of the paper.
%
%The inputs are:
%       a--the point where the differential is evaluated
%       b--the cosine series of the dispersion kernel
%       c--the cosine series of the carying capacity
%       mu-the reproductive rate of the species
%       N the projection dimension (number of cosine modes)
%
%Note that N is not actually used in this version of the function.
%Note also that the function uses the intlab implementation of the 
%fft or discrete convolution product



m=length(a);

i2=intval(2);

% We make sure that the inputs for FFT are powers of 2 %
m1=(2^ceil(log(4*m-1)/log(2))-4*m)/2;   % Hence 4*m+2*m1 is a power of 2 %

ta=[intval(zeros(m+m1+1,1));flip(a(2:m),1);a;intval(zeros(m+m1,1))];
tc=[intval(zeros(m+m1+1,1));flip(c(2:m),1);c;intval(zeros(m+m1,1))];

tu=verifyfft(ifftshift(ta),-1);
tv=verifyfft(ifftshift(tc),-1);

AC=fftshift(verifyfft(tu.*tv),1);

ac=real((4*m+2*m1)*AC(m1+m+2:m1+4*m-1));

DF_nonlinear=intval(zeros(m));

DF_nonlinear(:,1)=i2*ac(m:2*m-1);

k=(0:m-1)';

for ell=1:m-1
    DF_nonlinear(:,ell+1)=i2*(ac(k-ell+m)+ac(k+ell+m));
end 

D=mu*diag(b)-mu*diag(b)*DF_nonlinear;

end


%Old Version: 
% L = intval(zeros(N+1, N+1));
% for n = 0:N
%    L(n+1, n+1) = b(n+1); 
% end
% 
% A = convolutionMatrix_cos_intval(a, N);
% C = convolutionMatrix_cos_intval(c, N);
% 
% M = C*A;
% 
% D = mu*L - 2*mu*L*M;
