function Fa = kotSchaffer_logistic_intval(a, b, c, mu, N)

%--------------------------------------------------------------------------
%
%Note: In this file ``the paper'' refers to 
%
%      Fourier-Taylor Approximation of Unstable Manifolds for Compact Maps: 
%          Numerical Implementation and Computer Assisted Error Bounds
%
%
%
%The program evaluates the cosine series discretization of the
%Kot-Schaffer map.  The map is assumed to have logistic nonlinearity.
%
%More precisely the code implements the mapping defined by Equation 
%(18) on page 13 of the paper.
%
%The inputs are:
%       a--the variable of the map
%       b--the cosine series of the dispersion kernel
%       c--the cosine series of the carying capacity
%       mu-the reproductive rate of the species
%       N the projection dimension (number of cosine modes)
%
%Note that N is not actually used in this version of the function.
%Note also that the function uses the intlab implementation of the 
%fft or discrete convolution product

aac=int_cubic_sumFFT(c,a,a);
Fa = mu*b.*(a - aac); 


end 




