function PMN = computeKotSchafferManifold_1D(...
    p, lambda, xi, M, N, b, c, mu, nu)

%--------------------------------------------------------------------------
%
%Note: In this file ``the paper'' refers to 
%
%      Fourier-Taylor Approximation of Unstable Manifolds for Compact Maps: 
%          Numerical Implementation and Computer Assisted Error Bounds
%
%
%
%This program implements the Newton method for the 
%one dimensional unstable manifold for Kot-Schaffer 
%as discussed in Ramark 4.4. of Section 4.2.   The discretized operator
%Phi^{MN} and its differential are defined in Equation (42) and just after
%--------------------------------------------------------------------------

PMN = zeros(N+1, M+1);
PMN(:, 1) = p;
PMN(:, 2) = xi;


for n = 1:8
    
    PMN_old = PMN;
   
    %See equation 42
    Phi_P = Phi_KotSchaffer(PMN, M, N, p, lambda, xi, mu, b, c);
    
    %The solver below utilizes the lower triangular structure
    %of the truncated differential in order to speed up computations
    Delta = PhiDifferentialSolve_KotSchaffer(...
        PMN, -Phi_P, M, N, p, lambda, xi, mu, b, c);
    
    PMN = PMN + Delta;
    
    delta_n = Xnorm(PMN - PMN_old, nu, M, N);
    
end


end

