% Function to compute ingredients for Z_1 bounds 


function y = Z_1dualestimates(d,nu)

% The function expects as input a vector d of length 2N which are the last
% 2N components of (c^N \ast p_j)_n in our estimates which has length 2N+1

% Implements the formula

% max_{k = N+1,...2N+n}\frac{abs(d(k-n))}{2*nu^k} + 
% max_{k = N+1,...,2N-n}\frac{abs(d(k+n))}{2*nu^k}

% for n = 0,...,N

% Note that the second term is empty for n = N.

N = length(d)/2;

% if(~isinteger(N))
%     error('Wrong input length')
% end

% We define (N+1)x(2N) and NxN matrices containing the correctly
% shifted version of (parts of) d and the weight matrices.

D1 = intval(zeros(N+1,2*N)); D2 = intval(zeros(N,N));
W1 = D1; W2 = D2;

for n = 0:N
 D1(n+1,N+1-n:2*N) = d(N+1-n:2*N);
 W1(n+1,N+1-n:2*N) = (2*nu).^-(N+1:2*N+n);
 if(n<=N-1)
 D2(n+1,n+1:N) = d(N+1+n:2*N);
 W2(n+1,n+1:N) = (2*nu).^-(N+1:2*N-n);
 end
end



y = max(abs(sup(D1)).*sup(W1),[],2) + [max(abs(sup(D2)).*sup(W2),[],2);0];   % gives a column vector of the maxima of the rows (opposed to the standard matrix max which would give the max of the columns)